@@ -265,12 +265,15 @@ fetchHenry <- function(what='all', usersiteid=NULL, project=NULL, sso=NULL, gran
   opt.original <- options(stringsAsFactors = FALSE)
   
   # sanity-check: `what` should be within the legal set of options
-  if(! what %in% c('all', 'sensors', 'soiltemp', 'soilVWC', 'airtemp'))
-    stop("`what` must be either: 'all', 'sensors', 'soiltemp', 'soilVWC', or 'airtemp'", call.=FALSE)
+  if(! what %in% c('all', 'sensors', 'soiltemp', 'soilVWC', 'airtemp', 'waterlevel'))
+    stop("`what` must be either: 'all', 'sensors', 'soiltemp', 'soilVWC', 'airtemp', or 'waterlevel'", call.=FALSE)
   
   # sanity-check: user must supply some kind of criteria
-  if(missing(usersiteid) & missing(project) & missing(sso))
-    stop('you must provide some filtering criteria', call.=FALSE)
+  if(what != 'sensors') {
+    if(missing(usersiteid) & missing(project) & missing(sso))
+      stop('you must provide some filtering criteria', call.=FALSE)
+  }
+  
   
   # init empty filter
   f <- vector()
@@ -308,9 +311,6 @@ fetchHenry <- function(what='all', usersiteid=NULL, project=NULL, sso=NULL, gran
   # combine filters
   f <- paste(f, collapse='')
   
-  # debugging
-#   print(f)
-  
   # everything in one URL / JSON package
   json.url <- URLencode(paste('http://soilmap2-1.lawr.ucdavis.edu/henry/query.php?what=', what, f, sep=''))
   
@@ -322,17 +322,17 @@ fetchHenry <- function(what='all', usersiteid=NULL, project=NULL, sso=NULL, gran
   # parse JSON into list of DF
   try(s <- jsonlite::fromJSON(gzfile(tf.json)))
   
-  # report missing data
-  if(is.null(s$sensors)) {
+  # report query that returns no data and stop
+  if( length(s$sensors) == 0 ) {
     stop('query returned no data', call.=FALSE)
   }
   
-
-  # if we have some data...
-  if( !is.null(s$soiltemp)) {
+  
+  # post-process data, if there are some
+  if( length(s$soiltemp) > 0 | length(s$soilVWC) > 0 | length(s$airtemp) > 0 | length(s$waterlevel) > 0 ) {
     
     # get period of record for each sensor, not including NA-padding
-    por <- ddply(na.omit(rbind(s$soiltemp, s$soilVWC, s$airtemp)), c('sid'), function(i) {
+    por <- ddply(na.omit(rbind(s$soiltemp, s$soilVWC, s$airtemp, s$waterlevel)), c('sid'), function(i) {
       start.date <- min(i$date_time, na.rm=TRUE)
       end.date <- max(i$date_time, na.rm=TRUE)
       return(data.frame(start.date, end.date))
@@ -345,9 +345,10 @@ fetchHenry <- function(what='all', usersiteid=NULL, project=NULL, sso=NULL, gran
     s$soiltemp <- .formatDates(s$soiltemp, gran=gran, pad.missing.days=pad.missing.days)
     s$soilVWC <- .formatDates(s$soilVWC, gran=gran, pad.missing.days=pad.missing.days)
     s$airtemp <- .formatDates(s$airtemp, gran=gran, pad.missing.days=pad.missing.days)
+    s$waterlevel <- .formatDates(s$waterlevel, gran=gran, pad.missing.days=pad.missing.days)
     
     # optionally compute summaries, requires padded NA values and, daily granularity
-    if(soiltemp.summaries & pad.missing.days) {
+    if(soiltemp.summaries & pad.missing.days & (length(s$soiltemp) > 0)) {
       message('computing un-biased soil temperature summaries')
       
       if(gran != 'day')
@@ -380,6 +381,11 @@ fetchHenry <- function(what='all', usersiteid=NULL, project=NULL, sso=NULL, gran
     s$airtemp$name <- paste0(s$sensors$name[name.idx], '-', s$sensors$sensor_depth[name.idx])
   }
   
+  if(length(s$waterlevel) > 0) {
+    name.idx <- match(s$waterlevel$sid, s$sensors$sid)
+    s$waterlevel$name <- paste0(s$sensors$name[name.idx], '-', s$sensors$sensor_depth[name.idx])
+  }
+  
   # init coordinates
   if(!is.null(s$sensors)) {
     coordinates(s$sensors) <- ~ wgs84_longitude + wgs84_latitude
