@@ -1,4 +1,5 @@
-getHzErrorsPedonPC <- function(dsn, test.NA=FALSE, strict=TRUE) {
+## TODO: this isn't really needed any more
+getHzErrorsPedonPC <- function(dsn, strict=TRUE) {
 	
 	# get data
 	site_data <- get_site_data_from_pedon_db(dsn)
@@ -8,13 +9,13 @@ getHzErrorsPedonPC <- function(dsn, test.NA=FALSE, strict=TRUE) {
 	f <- join(hz_data, site_data, by='peiid', type='inner')
 	
 	# ignore missing lower boundary
-	f.test <- ddply(f, 'pedon_id', test_hz_logic, topcol='hzdept', bottomcol='hzdepb', test.NA=test.NA, strict=strict)
+	f.test <- ddply(f, 'pedon_id', test_hz_logic, topcol='hzdept', bottomcol='hzdepb', strict=strict)
 	
 	# find bad ones
 	bad.pedon.ids <- as.character(f.test$pedon_id[which(f.test$hz_logic_pass == FALSE)])
 	
 	# now describe the problems
-	b <- subset(f, select=c('pedon_id','hzdept','hzdepb','hzname'), subset=pedon_id %in% bad.pedon.ids)
+	b <- f[which(f$pedon_id %in% bad.pedon.ids), c('pedon_id','hzdept','hzdepb','hzname')]
 	
 	return(b) 
 	
