@@ -1,7 +1,4 @@
 ## 2013-01-08: now much faster since we only mix/clean data with > 1 color / horizon
-## consider mixing and returning closest Munsell color... does this make sense in RGB color space?
-## consider getting only the most common color?
-## consider returning the most common hue?
 
 # results can be referenced via phiid (horizon-level ID)
 get_colors_from_NASIS_db <- function() {
@@ -30,8 +27,15 @@ FROM
 	# close connection
   RODBC::odbcClose(channel)
 	
-  # mix colors as-needed
-  d.final <- simplifyColorData(d)
+  # sanity check, only attempt to simplify colors if there are > 1 rows
+  if(nrow(d) > 1) {
+    # mix colors as-needed, mixing done in CIE LAB space
+    d.final <- simplifyColorData(d)
+  } else {
+    # TODO: this could lead to problems due to assumed column presence
+    # do nothing
+    d.final <- d
+  }
   
 	# done
 	return(d.final)
