@@ -6,6 +6,11 @@
 
 
 get_site_data_from_pedon_db <- function(dsn) {
+  
+  # must have RODBC installed
+  if(!requireNamespace('RODBC'))
+    stop('please install the `RODBC` package', call.=FALSE)
+  
   q <- "SELECT site.siteiid, pedon.peiid, upedonid as pedon_id, site.usiteid as site_id, siteobs.obsdate as obs_date,
   latdegrees + IIF(IsNull(latminutes), 0.0, latminutes/ 60.0) + IIF(IsNULL(latseconds), 0.0, latseconds / 60.0 / 60.0) as y,
   -(longdegrees + IIF(IsNull(longminutes), 0.0, longminutes / 60.0) + IIF(IsNull(longseconds), 0.0, longseconds / 60.0 / 60.0)) as x,
@@ -29,13 +34,13 @@ LEFT OUTER JOIN (SELECT * FROM metadata_domain_detail WHERE domain_id = 971) AS
 ORDER BY site.usiteid;"
 
   # setup connection to our pedon database
-  channel <- odbcConnectAccess2007(dsn, readOnlyOptimize=TRUE)
+  channel <- RODBC::odbcConnectAccess2007(dsn, readOnlyOptimize=TRUE)
 
   # exec query
-  d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
+  d <- RODBC::sqlQuery(channel, q, stringsAsFactors=FALSE)
 
   # close connection
-  odbcClose(channel)
+  RODBC::odbcClose(channel)
   
   # warn if mixed datums
   unique.datums <- unique(na.omit(d$datum))
