@@ -7,17 +7,19 @@ seriesExtentAsGmap <- function(s, timeout=60, exp=1.25) {
 	x <- seriesExtent(s, timeout)
 	
 	# make extent object around sites, in geographic coordinates
-	e <- extent(spTransform(x, CRS('+proj=longlat')))
+	e <- raster::extent(sp::spTransform(x, sp::CRS('+proj=longlat')))
 	
 	# grab ref. to google maps
 	g <- dismo::gmap(e, exp=exp)
 	
 	# convert our points to Mercatur projection
-	x.M <- spTransform(x, CRS('+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +no_defs'))
+	x.M <- sp::spTransform(x, sp::CRS('+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +no_defs'))
 	
 	# plot google map, and our point of interest
-	plot(g, interpolate=TRUE)
-	plot(x.M, col=rgb(1, 0, 0, alpha=0.5), add=TRUE)
+	# note: have to use special plot methods
+	# http://stackoverflow.com/questions/38818682/self-authored-package-load-plot-method-for-spatialpolygonsdataframe
+	raster::plot(g, interpolate=TRUE)
+	sp::plot(x.M, col=rgb(1, 0, 0, alpha=0.5), add=TRUE)
 }
 
 
@@ -44,6 +46,9 @@ seriesExtent <- function(s, timeout=60) {
   x <- rgdal::readOGR(dsn=tf.json, layer='OGRGeoJSON', verbose=FALSE)
   unlink(tf.json)
   
+  # reset row names in attribute data to series name
+  x <- spChFIDs(x, as.character(x$series))
+  
   # return in WGS84 GCS
   return(x)
 }
